;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "poly-R" "20250502.1525"
  "Various polymodes for R language."
  '((emacs         "25")
    (ess           "25")
    (polymode      "0.2.2")
    (poly-markdown "0.2.2")
    (poly-noweb    "0.2.2"))
  :url "https://github.com/polymode/poly-R"
  :commit "fee0b6e99943fa49ca5ba8ae1a97cbed5ed51946"
  :revdesc "fee0b6e99943"
  :keywords '("languages" "multi-modes"))
